@@ -13,14 +13,11 @@
 
 #define LLDB_HAVE_EL_RFUNC_T 1
 
-
-#define HAVE_SYS_TYPES_H 1
-
 #define HAVE_SYS_EVENT_H 0
 
 #define HAVE_PPOLL 1
 
-#define HAVE_SIGACTION 1
+#define HAVE_PTSNAME_R 1
 
 #define HAVE_PROCESS_VM_READV 1
 
@@ -36,20 +33,30 @@
 
 #define LLDB_ENABLE_LZMA 1
 
+#define LLVM_ENABLE_CURL 0
+
 #define LLDB_ENABLE_CURSES 1
 
+#define CURSES_HAVE_NCURSES_CURSES_H 0
+
 #define LLDB_ENABLE_LIBEDIT 1
 
-#define LLDB_ENABLE_LIBXML2 1
+#define LLDB_ENABLE_LIBXML2 0
 
 #define LLDB_ENABLE_LUA 0
 
-#define LLDB_ENABLE_PYTHON 1
+#define LLDB_ENABLE_PYTHON 0
+
+#define LLDB_ENABLE_FBSDVMCORE 0
 
 #define LLDB_EMBED_PYTHON_HOME 0
 
 /* #undef LLDB_PYTHON_HOME */
 
-#define LLDB_LIBDIR_SUFFIX ""
+#define LLDB_INSTALL_LIBDIR_BASENAME "lib"
+
+/* #undef LLDB_GLOBAL_INIT_DIRECTORY */
+
+#define LLDB_BUG_REPORT_URL "https://github.com/llvm/llvm-project/issues/"
 
 #endif // #ifndef LLDB_HOST_CONFIG_H
